@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -368,7 +368,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -378,7 +378,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
