@@ -86,7 +86,7 @@
 #define KNTLM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNTLM_NO_DEPRECATED
-#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KNTLM_NO_DEPRECATED_WARNINGS
 #  define KNTLM_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNTLM_DEPRECATED_WARNINGS_SINCE KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
@@ -180,7 +180,7 @@
 #define KNTLM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNTLM_NO_DEPRECATED
-#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
+#  define KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
 #endif
 #ifdef KNTLM_NO_DEPRECATED_WARNINGS
 #  define KNTLM_DEPRECATED_WARNINGS_SINCE 0
@@ -190,7 +190,7 @@
 #  ifdef KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNTLM_DEPRECATED_WARNINGS_SINCE KNTLM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x55c00
+#    define KNTLM_DEPRECATED_WARNINGS_SINCE 0x55f00
 #  endif
 #endif
 
